hash_thumbnail_params

Function hash_thumbnail_params 

pub fn hash_thumbnail_params(
    aspect: (u32, u32),
    short_edge: u32,
    quality: u32,
    sharpening: Option<(f32, i32)>,
) -> String
SHA-256 hash of encoding parameters for a thumbnail.

Inputs: aspect ratio, short edge size, quality, and sharpening settings. If any of these change, the thumbnail is re-generated.